@@ -47,67 +47,6 @@ setMethodS3("getDefaultColumnNames", "AromaCellPositionFile", function(this, ...
 }, protected=TRUE)
 
 
-
-setMethodS3("byChipType", "AromaCellPositionFile", function(static, chipType, tags=NULL, nbrOfCells=NULL, ..., verbose=FALSE) {
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Validate arguments
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Argument 'chipType':
-  chipType <- Arguments$getCharacter(chipType, length=c(1,1));
-
-  # Argument 'nbrOfCells':
-  if (!is.null(nbrOfCells)) {
-    nbrOfCells <- Arguments$getInteger(nbrOfCells, range=c(0,Inf));
-  }
-
-  # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
-  if (verbose) {
-    pushState(verbose);
-    on.exit(popState(verbose));
-  }
-
-
-  verbose && enter(verbose, "Locating ", class(static)[1]);
-  pathname <- findByChipType(static, chipType=chipType, tags=tags,
-      firstOnly=TRUE, ...);
-  if (is.null(pathname)) {
-    ext <- getDefaultExtension(static);
-    note <- attr(ext, "note");
-    msg <- sprintf("Failed to create %s object. Could not locate an annotation data file for chip type '%s'", class(static)[1], chipType);
-    if (is.null(tags)) {
-      msg <- sprintf("%s (without requiring any tags)", msg);
-    } else {
-      msg <- sprintf("%s with tags '%s'", msg, paste(tags, collapse=","));
-    }
-    msg <- sprintf("%s and with filename extension '%s'", msg, ext);
-    if (!is.null(note)) {
-      msg <- sprintf("%s (%s)", msg, note);
-    }
-    msg <- sprintf("%s.", msg);
-    throw(msg);
-  }
-
-  verbose && cat(verbose, "Located file: ", pathname);
-  res <- newInstance(static, pathname);
-  verbose && print(verbose, res);
-
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  # Validation?
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  if (!is.null(nbrOfCells)) {
-    if (nbrOfCells(res) != nbrOfCells) {
-      throw("The number of cells in the loaded ", class(static)[1], " does not match the expected number: ", nbrOfCells(res), " != ", nbrOfCells);
-    }
-  }
-
-  verbose && exit(verbose);
-
-  res;
-}, static=TRUE)
-
-
-
 setMethodS3("readPositions", "AromaCellPositionFile", function(this, cells=NULL, drop=FALSE, ..., verbose=FALSE) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
@@ -218,6 +157,9 @@ setMethodS3("allocate", "AromaCellPositionFile", function(static, ..., nbrOfCell
 
 ############################################################################
 # HISTORY:
+# 2014-06-28
+# o CLEANUP: Move byChipType() from classes AromaCellCpgFile and
+#   AromaCellPositionFile to superclass AromaCellTabularBinaryFile.
 # 2009-02-16 [HB]
 # Removed argument 'validate' from byChipType() of AromaCellPositionFile.
 # 2009-02-10 [HB]
