@@ -574,7 +574,8 @@ setMethodS3("writeRegions", "CopyNumberSegmentationModel", function(this, arrays
     verbose && enter(verbose, sprintf("Array #%d ('%s') of %d",
                                                aa, name, length(arrays)));
     df <- getRegions(this, arrays=array, ..., verbose=less(verbose))[[1]];
-    names(df) <- gsub("Smoothing", "log2", names(df));
+    names(df) <- gsub("(Smoothing|mean)", "log2", names(df))
+    verbose && str(verbose, df)
 
     if (nrow(df) > 0) {
       if (identical(format, "xls")) {
@@ -678,7 +679,7 @@ ylim <- c(-1,1);
       # Write data
       verbose && str(verbose, df);
       write.table(df, file=pathname, sep="\t", col.names=FALSE,
-                  row.names=FALSE, quote=FALSE, append=oneFile);
+                  row.names=FALSE, quote=FALSE, append=TRUE)
     }
     verbose && exit(verbose);
     res[[array]] <- df;
